#
# spec file for package python-docutils
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
Name:           python-docutils%{psuffix}
Version:        0.20.1
Release:        1699.4.pm.4
Summary:        Python Documentation Utilities
License:        BSD-2-Clause AND Python-2.0 AND GPL-2.0-or-later AND GPL-3.0-or-later AND SUSE-Public-Domain
URL:            https://pypi.python.org/pypi/docutils/
Source:         https://files.pythonhosted.org/packages/source/d/docutils/docutils-%{version}.tar.gz
Source99:       python-docutils-rpmlintrc
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(pre):  update-alternatives
Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     python-Pillow
Recommends:     python-Pygments
Recommends:     python-roman
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module Pillow}
BuildRequires:  %{python_module Pygments}
BuildRequires:  %{python_module packaging}
# BuildRequires:  %%{python_module roman}
%endif
%if "%{python_flavor}" == "python3" || "%{?python_provides}" == "python3"
Provides:       docutils = %{version}
Obsoletes:      docutils < %{version}
%endif
%python_subpackages

%description
Docutils is a modular system for processing documentation into useful formats,
such as HTML, XML, and LaTeX. For input Docutils supports reStructuredText, an
easy-to-read, what-you-see-is-what-you-get plaintext markup syntax.

%prep
%autosetup -p1 -n docutils-%{version}
# Remove useless ".py" ending from executables:
for i in tools/rst*; do mv "$i" "${i/.py}"; done
sed -i "s|'tools/\(rst.*\)\.py'|'tools/\1'|" setup.py
find . -name \*.mp4 -print -exec chmod -x '{}' \;

# Actually seems to work with Python 3.6
sed -i -e '/python_requires/ s/7/6/' setup.py

# Remove shebang from non-executable files
sed -i '1{/^#!/d}' \
  docutils/__main__.py \
  docutils/parsers/commonmark_wrapper.py \
  docutils/parsers/recommonmark_wrapper.py \
  docutils/utils/error_reporting.py \
  docutils/utils/math/math2html.py \
  docutils/utils/math/tex2unichar.py \
  docutils/utils/smartquotes.py \
  docutils/writers/_html_base.py \
  docutils/writers/odf_odt/prepstyles.py \
  docutils/writers/xetex/__init__.py

%build
%pyproject_wheel

%install
%if !%{with test}
%pyproject_install
for binary in docutils rst2html rst2latex rst2man rst2odt rst2odt_prepstyles rst2pseudoxml rst2s5 rst2xetex rst2xml rstpep2html rst2html4 rst2html5 ; do
    %python_clone -a %{buildroot}%{_bindir}/$binary
done
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%check
%if %{with test}
%python_exec test/alltests.py -v
%endif

%if !%{with test}
# sometime ago rst2html was the master which would let fail the upgrade with master docutils in post below
%pre
update-alternatives --query rst2html >/dev/null 2>&1 && update-alternatives --quiet --remove-all rst2html ||:

%post
%python_install_alternative docutils rst2html rst2latex rst2man rst2odt rst2odt_prepstyles rst2pseudoxml rst2s5 rst2xetex rst2xml rstpep2html rst2html4 rst2html5

%postun
%python_uninstall_alternative docutils

%files %{python_files}
%license COPYING.txt licenses/*.txt
%doc FAQ.txt HISTORY.txt README.txt THANKS.txt BUGS.txt docs/*
%python_alternative %{_bindir}/docutils
%python_alternative %{_bindir}/rst2html
%python_alternative %{_bindir}/rst2latex
%python_alternative %{_bindir}/rst2man
%python_alternative %{_bindir}/rst2odt
%python_alternative %{_bindir}/rst2odt_prepstyles
%python_alternative %{_bindir}/rst2pseudoxml
%python_alternative %{_bindir}/rst2s5
%python_alternative %{_bindir}/rst2xetex
%python_alternative %{_bindir}/rst2xml
%python_alternative %{_bindir}/rstpep2html
%python_alternative %{_bindir}/rst2html4
%python_alternative %{_bindir}/rst2html5
%{python_sitelib}/docutils/
%{python_sitelib}/docutils-%{version}.dist-info
%endif

%changelog
* Sat Mar 30 2024 Ben Greiner <code@bnavigator.de>
- Fix update-alternatives updates: docutils is the master but
  rst2html from old installations can create update failures
- Fix bytecode cache errors: Don't modify python scripts after
  install
* Fri Feb 23 2024 Dan Čermák <dcermak@suse.com>
- Drop obsolete Requires & BuildRequires on python-packaging & python-xml
* Fri Nov 10 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.20.1:
  * Include tox.ini and docutils.conf in the source package
  * Docutils 0.20 is the last version supporting Python 3.7 and 3.8.
  * Support Python 3.11 (patch #198 by Hugo van Kemenade).
  * New functions `rst2…()` for use as "console_scripts" `entry points`_.
  * Fix `previous_sibling()` method that led to invalid HTML in some cases
  * Fix bug #463. Spurious comma in deprecation warning.
  * Improved mock Sphinx module.
  * `Transformer.populate_from_components()` now silently ignores
    components that are not instances of `docutils.TransformSpec`.
  * Accept author names with initials like ``A. Einstein`` in the "author"
    `bibliographic field`_ instead of rising an error
  * `DanglingReferences` ignores `citation_reference` nodes if the
    "use_bibex" setting is active.
  * New utility function `xml_declaration()`.
  * `DependencyList.add()` accepts `pathlib.Path` instances.
  * Support "mod" notation for modulo operation / modulus arithmetic.
  * Wrap definition lists with "details" class argument in a <div>
    with the "id" and "class" values of the list node.
  * Use dpub-ARIA role "doc-footnote__" (instead of ARIA role "note")
    for footnotes.
  * Do not load the `inputenc` package in UTF-8 encoded LaTeX sources.
    (UTF-8 is the default encoding for LaTeX2e since 2018).
  * Fix behaviour of the use_bibtex_ setting.
  * Outsource parts of `depart_document()` to new auxiliary methods
    `make_title()` and `append_bibliography()`.
  * Drop ``\usepackage{fixltx2e}`` from template.
  * Fix SetuptoolsDeprecationWarning: ``Installing '' as data is deprecated``
    by adding data directories to package_data.packages list.
  * Refactored tests to use common `unittest` idioms.
- Drop pygments-2.14.patch, no longer needed.
* Fri Oct 13 2023 Matej Cepl <mcepl@cepl.eu>
- python-roman is not actually necessary for testing.
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Sun Apr 16 2023 Matej Cepl <mcepl@suse.com>
- Update single spec from Factory
* Tue Jan 24 2023 Steve Kowalik <steven.kowalik@suse.com>
- Refactor pygments-2.14.patch to not use distutils.
* Tue Jan 10 2023 Daniel Garcia <daniel.garcia@suse.com>
- Delete sphix-6.0.0.patch
- Add pygments-2.14.patch
- The patch is related to pygments not Sphinx and the patch is updated to make
  it conditional so it work with older versions of pygments, shp#docutils#201
* Wed Jan  4 2023 Daniel Garcia <daniel.garcia@suse.com>
- Add sphinx-6.0.0.patch to fix tests for new version of sphinx.
* Wed Nov  2 2022 Matej Cepl <mcepl@suse.com>
- Release 0.19 (2022-07-05)
  - General
  - Dropped support for Python 2.7, 3.5, and 3.6. and removed
    compatibility hacks from code and tests.
  - Code cleanup, check PEP 8 conformity with flake8
    (exceptions in file tox.ini).
  - New module. Support for python -m docutils. Also used for
    the docutils console script entry point.
  - Let Publisher.publish() print info and prompt
    when waiting for input from a terminal (cf.
    https://clig.dev/#interactivity).
  - Respect "input_encoding_error_handler" setting when opening
    a source.
  - New function error_string() obsoletes
    utils.error_reporting.ErrorString.
  - Class ErrorOutput moved here from utils/error_reporting.
  - Use "utf-8-sig" instead of Python's default encoding if the
    "input_encoding" setting is None.
  - Fix error when reading of UTF-16 encoded source without
    trailing newline.
  - Aliases "markdown" and "commonmark" point to
    "commonmark_wrapper".
  - Alias for the "myst" parser
    (https://pypi.org/project/myst-docutils).
  - Use absolute module names in _parser_aliases instead
    of two import attempts. (Keeps details if the
    recommonmark_wrapper.py module raises an ImportError.)
  - Prepend parser name to ImportError if importing a parser
    class fails.
  - New module for parsing CommonMark input. Selects a
    locally installed 3rd-party parser (pycmark, myst, or
    recommonmark).
  - Raise ImportError, if import of the upstream parser
    module fails. If called from an "include" directive, the
    system-message now has source/line info.
  - Adapt to and test with "recommonmark" versions 0.6.0 and
    0.7.1.
  - Update PEP base URL (fixes bug #445), use "https:" scheme
    in RFC base URL.
  - Add reporter to Directive class attributes.
  - parser_name() keeps details if converting ImportError to
    ValueError.
  - Don't use mutable default values for function
    arguments. Fixes bug #430.
  - Fix bug #435: invalid references in problematic nodes with
    report_level=4.
  - decode_path() returns str instance instead of
    nodes.reprunicode.
  - Add deprecation warning.
  - Add "html writers" to config_section_dependencies. Fixes
    bug #443.
  - Write table column widths with 3 digits precision. Fixes
    bug #444.
  - Add space before "charset" meta tag closing sequence.
  - Remove class value "controls" from an image node with video
    content after converting it to a "control" attribute of the
    <video> tag.
  - Wrap groups of footnotes in an <aside> for easier styling.
  - Use "https:" scheme in "python_home" URL default.
  - Fix links in template.txt.
  - New "docutils" console script entry point. Fixes bug #447.
  - Always encode the log file "alltests.out" using 'utf-8'.
  - exception_data() now returns None if no exception was
    raised.
  - recommonmark_wrapper only imported if upstream parser is
    present.
  - Fix bug #436: Null char valid in CSV since Python 3.11.
  - Allow 3rd-party drop-in components for reader and parser,
    too.
  - Fix help output.
  - Actual code moved to docutils.__main__.py.
  - Options -h and --help print short usage message.
- Release 0.18.1 (2021-11-23)
  - Node.traverse() returns a list again to restore backwards
    compatibility. Fixes bug #431.
  - New method Node.findall(): like Node.traverse() but returns
    an iterator. Obsoletes Node.traverse().
  - Fix behaviour of get_stylesheet_list(): do not look up
    stylesheets given as "stylesheet" setting. Cf. bug #434.
  - Fix handling of footnote_backlinks==False (report Alan G
    Isaac).
  - Fix typo (bug #432).
  - Fix spurious output with Windows (bug #350).
  - Fix a false positive (bug #434).
- Release 0.18 (2021-10-26)
  - mark as provisional (will switch from using "optparse" to
    "argparse").
  - remove hack for the now obsolete "mod_python" Apache
    module.
  - new function get_default_settings()
  - Don't change a list while looping over it (in
    document.set_name_id_map()). Thanks to Mickey Endito.
  - Test and update to work with recommonmark version
    0.6.0. Still provisional.
  - Unfortunately, recommonmark is no longer maintained.
  - Fix bug #424 Wrong circular inclusion detection. Use a
    "magic" comment instead of line numbers to keep a log of
    recursive inclusions.
  - Use a "magic" comment to update the log of recursive
    inclusions.
  - New option `image_loading`_. Support "lazy" loading of
    images. Obsoletes "embed_images".
  - Fix spelling of option "detailed".
  - Read settings from standard configuration files.
- Release 0.18b1 (2021-10-05)
  - The default value for the "auto_id_prefix" setting changed to
    "%%": auto-generated IDs use the tag name as prefix.
  - Make meta a standard Docutils doctree node. Writers may
    ignore "meta" nodes if they are not supported by the output
    format.
  - document.make_id(): Do not strip leading number and hyphen
    characters from name if the id_prefix setting is non-empty.
  - Node.traverse() returns an iterator instead of a list.
  - Removed. (Meta directive moved to misc.py.)
  - Meta directive class (moved from html.py) inserts meta
    (instead of pending) nodes.
  - Add class option to Raw directive.
  - Unify behaviour of "widths" option: check that the length of
    an integer list equals the number of table columns also for
    the "table" directive.
  - Fork from elyxer and remove code that is not required for
    math conversion.
  - Scale variable sized operators and big delimiters with CSS
  - Support more commands, fix mapping of commands to Unicode
    characters (cf. LaTeX syntax for mathematics).
  - Fix bug #244 Wrong subscript/superscript order.
  - Don't use <tt> element (deprecated in HTML5).
  - Use STIX fonts if available.
  - Fix source location (line number) for attribution
    elements. Patch by Mickey Endito.
  - Add line, source, and rawsource internal attributes for
    blockquote elements. Patch by Mickey Endito.
  - Skip system_messages when propagating targets. Fixes bug
    [#425].
  - Removed unique_combinations() (obsoleted by
    itertools.combinations()).
  - Major update (fixes and support for additional commands and
    symbols). Fixes bug #407.
  - Write footnote brackets and field term colons to HTML, so
    that they are present also without CSS and when copying
    text. Adapt minimal.css.
  - Use semantic tags <aside> for footnote text, topics,
    admonitions, and system-messages and <nav> for the table of
    contents. Use <div> for citations.
  - Only specify table column widths, if the "widths" option
    is set and is not "auto" (fixes bug #426). The table_style
    setting "colwidths-grid" restores the current default.
  - Use ARIA roles to enable accessible HTML for abstract,
    dedication, the table of contents, footnote, references,
    footnotes, citations, and backlinks.
  - Use "aria-level" attribute instead of invalid tags <h7>,
    <h8>, ... for headings of deeply nested sections.
  - Do not set classes "compound-first", "compound-middle",
    or "compound-last" to elements nested in a compound. Use
    class value "backrefs" instead of "fn-backref" for a span of
    back-references.
  - Do not write class values handled by the HTML writer
    ("colwidths-auto", "colwidths-given", "colwidths-grid") to
    the output.
  - Move space character between section number and heading into
    "sectnum" span.
  - Removed attribute HTMLTranslator.topic_classes
  - Items of a definition list with class argument "details" are
    converted to details disclosure elements.
  - Overwrite methods in _html_base.HTMLTranslator that use
    HTML5 tags (details, aside, nav, ...) and attributes (role,
    aria-level).
  - The setting legacy_class_functions now defaults to
    "False". Adapt stylesheets modifying \DUadmonition and/or
    \DUtitle.
  - Apply patch #181 "Fix tocdepth when chapter/part in use" by
    John Thorvald Wodder II.
  - Fix newlines after/before ids_to_labels() (cf. patch #183).
  - Refactor/revise ToC writing.
  - Don't add \phantomsection to labels in math-blocks.
  - Improve spacing and allow customization of Docutils-generated
    table of contents.
  - New algorithm for table column widths. Fixes bug #422. New
    configuration setting legacy_column_widths.
  - Table.set_table_style() arguments changed.
  - Only write "continued on next page..." if it fits without
    making the table columns wider.
  - Table width option overrides conflicting "auto" column
    widths.
  - Fix excessive padding above sidebar titles.
  - Fix option "detailed" under Python 2.7.
  - Remove IE 6 compatibility workarounds iepngfix.htc and
    blank.gif (fixes bug #169).
  - Fix: double quotes need to be escaped on macro
    invocation. Done everywhere.
* Sat Oct 16 2021 Dirk Müller <dmueller@suse.com>
- update to 0.17.1:
  * Fix bug #406 (MathML translation of ``\mathbf``).
  * Open "docutils.sty" with encoding set to "utf8".
  * Provide fallbacks for parser config settings
    to facilitate programmatic use.
  * Installing with ``setup.py`` now requires ``setuptools``.
    Alternatively, install with `pip`_ (or "manually").
  * Use importlib.import_module() to programmatically import modules.
  * Fix bug #385: Import of language modules.
  * Arabic mappings by Shahin.
  * Fixes in Korean translation by Shinjo Park.
  * Fix error when copying `system_message` node
  * Make the sidebar's "title" argument optional
  * Make "meta" elements available for "latex" and "odt".
  * Prevent infinite inclusion loops.
  * Move non-essential styling to ``plain.css``.
  * Support "captionbelow" class value for tables.
  * Display code line numbers as pseudo-elements which are skipped
    when copying text from code blocks. Solves feature request #32.
  * Support numbered figures.
  * New optional style that adapts to different screen sizes.
  * Fix #394 fix missing new line after rubric.
  * Patch #168 fix crashing on empty citation (by Takeshi KOMIYA).
  * Fix #126 manpage title with spaces.
  * Fix #380 commandline option problem in sphinx.
  * Fix/improve metadata handling:
    fix "keyword" splitting,
    allow generic fields (stored as "Custom Properties").
    __ docs/user/config.html#detailled
  * Run python3 test like python2 against source not the build/-directory
  * New generic command line front end that allows the free selection of
    reader, parser, and writer components.
- remove pygments25.patch (upstream)
* Sat Dec 12 2020 Benjamin Greiner <code@bnavigator.de>
- In a world with more than one python 3 flavor, provide "docutils"
  with the default python3 provider.
  gh#openSUSE/python-rpm-macros#66
* Tue Apr  7 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix the condition to really generate the direct binaries
* Mon Apr  6 2020 Matej Cepl <mcepl@suse.com>
- Remove %%python3_only and use full alternatives.
* Sat Mar 14 2020 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to fix build with pygments 2.4 and newer:
  * pygments25.patch
* Wed Jan 15 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.16:
  - Dropped support for Python 2.6, 3.3 and 3.4
  - Docutils now supports Python 2.7 and Python 3.5+ natively
    (without conversion by ``2to3``).
  - Keep `backslash escapes`__ in the document tree. Backslash characters in
    text are be represented by NULL characters in the ``text`` attribute of
    Doctree nodes and removed in the writing stage by the node's
    ``astext()`` method.
- Remove merged patch fix_tests_38.patch
* Fri Oct 11 2019 Matej Cepl <mcepl@suse.com>
- Add fix_tests_38.patch to overcome failing
  test_writers.test_odt.DocutilsOdtTestCase with Python 3.8.
  Also, failed as shp#docutils#161.
* Sat Sep 14 2019 John Vandenberg <jayvdb@gmail.com>
- Skip the tests for the flavors not being built
* Fri Aug  9 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.15.2
  * Docutils 0.14.x is the last version supporting Python 2.4, 2.5,
  3.1, and 3.2.
  * reStructured text: Allow embedded colons in field list field
    names (before, tokens like :this:example: were considered ordinary text).
  * Fixed a bug with the "trim" options of the "unicode" directive.
* Mon May 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add multibuild in order to avoid buildcycle with Pillow and friends
* Tue May  7 2019 John Vandenberg <jayvdb@gmail.com>
- Add optional build dependencies Pillow, Pygments and roman,
  causing 16 additonal test methods to run
- Add Recommends for Pillow, Pygments and roman
- Use %%license
- Simplify test invocation
* Wed Jan  9 2019 Matej Cepl <mcepl@suse.com>
- Remove unnecessary node BR
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Fri Nov 10 2017 arun@gmx.de
- specfile:
  * add binary rst2html4
- update to version 0.14:
  * Enable validation of Docutils XML documents against the DTD:
    Use attribute type NMTOKEN instead of REFID for the `refid` attribute
    and NMTOKENS for `backrefs`: REFID refers to an ID type instance,
    however, the `ids` attribute cannot use the ID type because `XML only
    allows one ID per Element Type`__ and doesn't support a multiple-ID
    "IDS" attribute type.
  * Added documentation for escaped whitespace in URI contexts.
  * Clarify use of Unicode character categories.
  * Added functionality: escaped whitespace in URI contexts.
  * Consistent handling of all whitespace characters in inline markup
    recognition. Fixes [ 307 ] and [ 3402314 ] (now [ 173 ]).
  * Added support for escaped whitespace in URI contexts.
  * Rework patch [ 120 ] (revert change to "Table.get_column_widths()"
    that led to problems in an application with a custom table
    directive).
  * Fix [ 320 ] Russian docinfo fields not recognized.
  * Don't add a second ID to problematic references.
  * Fix SmartQuotes: warn only once if language is unsupported, keep
    "rawsource" when "educating" quotes.
  * Added "split_escaped_whitespace" function, support for escaped
    whitespace in URI contexts.
  * Fix [ 321 ] Import block might cause name error.
  * Update quote definitions for languages et, fi, fr, ro, sv, tr, uk.
  * New quote definitions for hr, hsb, hu, lv, sh, sl, sr.
  * Fix [ 313 ] Differentiate apostrophe from closing single quote (if
    possible).
  * Fix [ 317 ] Extra space inserted with French smartquotes.
  * Add command line interface for stand-alone use (requires 2.7).
  * Provide default title in metadata (required by HTML5).
  * Fix [ 312 ] HTML writer generates invalid HTML if the table has
    two tags.
  * Fix [ 319 ] The MathJax CDN shut down on April 30, 2017. For
    security reasons, we don't use a third party public installation as default but
    warn if math-output_ is set to MathJax without specifying a URL.
  * Apply [ 125 ] HTML writer: respect automatic table column sizing.
  * Handle class arguments for block-level elements by wrapping them
    in a "DUclass" environment. This replaces the special handling for
    "epigraph" and "topic" elements.
  * Apply [ 141 ] Handling inline in manpage writer.
  * Command setting "language" now sets the default language of the
    generated ODF document.
  * The use of image directive options :width: (%%), :scale:, etc now
    set the width/height/size of images in the generated ODF
    documents.
  * The heading/title of admonitions now reflects the language
    specified by the "language" setting.
  * Fixed [ 306 ] only first of multiple "image" directives with the
    same URL shown in output.
  * Fixed [ 282 ] python3: AttributeError.
  * tools/rst2html4.py: New front-end.
  * tools/dev/generate_punctuation_chars.py: New skript to test and
    update utils.punctuation_chars.
* Tue Jun  6 2017 jmatejek@suse.com
- only emit rst2html5 alternatives for python 3
- switch the "docutils" provides to the python 3 package (all the comands live there)
  (this fixes bsc#1039394)
* Mon May  1 2017 toddrme2178@gmail.com
- Make only the python2 package provide the "docutils" package.
* Thu Apr 20 2017 toddrme2178@gmail.com
- Fix url
- Executables are python-independent so only have the python3
  version provide them.
- Implement update-alternatives to avoid conflict with rst2html5
* Fri Mar 24 2017 aloisio@gmx.com
- Converted to single-spec
- Added python-docutils-rpmlintrc
* Thu Mar  9 2017 dmueller@suse.com
- update to 0.13.1:
  * New HTML writer generating HTML 5.
  * languages: persian/farsi (fa) and latvian (la) mappings.
  * change default base url for :rfc: to http://tools.ietf.org/html/
  latex2e: Fix admonition width, remove deprecated options,
  better tablewidth auto, ...
* Mon Aug 15 2016 toddrme2178@gmail.com
- Fix update-alternatives implementation.
* Wed Oct 29 2014 Led <ledest@gmail.com>
- fix bashisms in pre script
* Tue Jul 15 2014 toddrme2178@gmail.com
- Update to 0.12
  * docs/ref/rst/directives.txt
  - Update "math" and "csv-table" descriptions.
  * docutils/parsers/rst/directives/images.py
  - Fix [258] figwidth="image" generates unitless width value.
  * docutils/parsers/rst/states.py
  - Improve error report when a non-ASCII character is specified as
    delimiter, quote or escape character under Python 2.
    Fixes [ 249 ] and [ 250 ].
  * docutils/writers/html4css1/__init__.py
  - Don't add newline after inline math.
    Thanks to Yury G. Kudryashov for the patch.
  * docutils/writers/latex2e/__init__.py
  - Fix [ 239 ] Latex writer glues paragraphs with figure floats.
  - Apply [ 116 ] by Kirill Smelkov. Don't hardcode \large for subtitle.
  * docutils/writers/odf_odt/__init__.py
  - Apply patch by Jakub Wilk to fix bug [ 100 ].
  * test/test_error_reporting.py
  - Fix [ 223 ] by removing redundant tests we do not have control over.
  * test/test_nodes.py
  - Apply [ 115 ] respect fixed 2to3 string literal conversion behavior.
* Tue Sep 24 2013 toddrme2178@gmail.com
- Update to 0.11
  * Fix for the overwritting of document attributes.
  * Support embedded aliases within hyperlink references.
  * try local import of docutils components (reader, writer, parser,
    language module) before global search.
  * Python 3.3 checks CVS syntax only if "strict" is True.
  * Now, it is easy to add a custom stylesheet to Docutils' default
    stylesheet with, e.g.,
  - -stylesheet_path='html4css1.css, mystyle.css'
  * If there is a file html4css1.css in the working directory of the
    process at launch, it is used instead of the one provided by
    Docutils in the writer source directory.
  * New default for math-output: HTML math.css.
  * Avoid repeated class declarations in html4css1 writer
  * Drop the simple algorithm replacing straight double quotes with
    English typographic ones. Activate the SmartQuotes transform if
    you want this feature.
  * New setting stylesheet_dirs: Comma-separated list of directories
    where stylesheets are found. Used by stylesheet_path when
    expanding relative path arguments.
  * handle lines starting with a period.
  * Fix option separating comma was bold (thanks to Bill Morris).
- Use pypi url and download
- Replace rpmlint-non-executable-scripts.diff with sed in the spec
  file
* Mon Sep 16 2013 tchvatal@suse.com
- Fix the symlink creation.
* Mon Sep 16 2013 tchvatal@suse.com
- Drop r7486-python33-compat.patch as it is not needed.
* Mon Sep 16 2013 tchvatal@suse.com
- Use update-alternatives to allow switching between py2 and py3
  version of doctool binaries.
* Wed Jul  3 2013 dmueller@suse.com
- update to 0.10:
  - add rpmlint-non-executable-scripts.diff
  * SmartQuotes transform for typographic quotes and dashes.
  * FileInput/FileOutput: no system-exit on IOError. The handle_io_errors option is ignored.
  * <code> tag for inline "code", do not drop nested inline nodes (syntax highlight tokens).
  * Customizable MathJax URL (based on patch by Dmitry Shachnev).
  * No line break after opening inline math tag.
* Tue Nov 20 2012 saschpe@suse.de
- Run testsuite
- Correctly fix non-excutable script warning
- Remove outdated macros
- Also remove "*.py" ending in egg-info files
* Fri Oct 26 2012 highwaystar.ru@gmail.com
- patch from upstream for python3.3 support
  * Fix [3541369] Relative __import__ also with Python 3.3
* Thu May  3 2012 toddrme2178@gmail.com
- Update to version 0.9:
  * reStructuredText "code" role and directive with syntax
    highlighting by Pygments_.
  * "code" option of the "include" directive.
  * Fix [ 3402314 ] allow non-ASCII whitespace, punctuation
    characters and "international" quotes around inline markup.
  * Fix handling of missing stylesheets.
  * Fix [ 2971827 ] and [ 3442827 ] extras/roman.py moved to
    docutils/utils/roman.py
  * docutils.utils is now a package (providing a place for
    sub-modules)
  * change default for `math-output` setting to MathJax
  * Support the `abbreviation` and `acronym` standard roles.
  * Record only files required to generate the LaTeX source as
    dependencies.
  * Use ``\setcounter{secnumdepth}{0}`` instead of ``*``-versions
    when suppressing LaTeX section numbering.
- Cleaned up spec files
- Fix rpmlint warnings
* Mon Apr 30 2012 cfarrell@suse.com
- license update: Python-2.0 and BSD-2-Clause and GPL-2.0+ and GPL-3.0+ and
  SUSE-Public-Domain
  tools/editors/emacs/rst.el is GPL-3.0+ - see also COPYING file
* Fri Apr 27 2012 toddrme2178@gmail.com
- Fix building python 3 package on openSUSE 11.4 x86_64
* Tue Apr 24 2012 saschpe@suse.de
- Disable testsuite altogether, fails also on the bleeding_edge_* repos
* Tue Feb 28 2012 saschpe@suse.de
- Fixed SLE_11_SP2 build by disabling the testsuite
* Fri Sep 23 2011 saschpe@suse.de
- Fixed build:
  * python-xml is only required on SUSE
  * pyxml is required on Fedora (and RHEL)
* Wed Sep 21 2011 saschpe@suse.de
- Don't run tests on SLE, they break the build
* Wed Sep 21 2011 saschpe@suse.de
- Renamed to python-docutils (from docutils), also fixes rpmlint
  warning about naming policy
- Update to version 0.8.1:
  * Change last file with Apache license to BSD-2-Clause and correct copyright
    info for rst.el
  * Fix tests under py3k.
  * Clean up Babel language setting. Restores Sphinx compatibility.
- Changes from version 0.8.0:
  * Some additions to the Docutils core are released under the 2-Clause BSD
    license.
  * Handle language codes according to BCP 47.
  * If the specified langauage is not supported by Docutils, warn and fall
    back to English.
  * Math support: reStructuredText "math" role and directive, math and
    math_block doctree elements.
  * Orphaned "python" reader and "newlatex2e" writer moved to the sandbox.
  * Added lithuanian mappings.
- Changes from version 0.7.0:
  * Support SVG and SWF images
  * Generate valid XHTML for centered images with targets. Use CSS classes
    instead of "align" tags for image alignment.
  * Preserve runs of spaces in 'inline literals'.
  * Deprecate figure_footnotes setting.
  * Rename use_latex_footnotes setting to docutils_footnotes.
  * New latex_preamble setting.
  * Use PDF standard fonts (Times/Helvetica/Courier) as default.
  * hyperref package called with unicode option
  * Drop the special output_encoding default ("latin-1"). The Docutils wide
    default (usually "UTF-8") is used instead.
- Spec file cleanup:
  * Removed outdated docutils-0.6-insecure-temp.patch
  * Fixed non-executable scripts rpmlint warning
  * Removed ".py" ending from executables in /usr/bin, this is what
    other Python packages expect anyway
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
* Mon Dec 20 2010 saschpe@suse.de
- reduce rpmlint complaints:
  * name in summary
  * executables in doc package ('tools' folder)
* Sun Dec 12 2010 saschpe@gmx.de
- update to 0.6
  * support for SVG and SWF images in HTML writer
  * many improvements in LaTeX2e writer
- re-generated spec file with py2pack
  * now builds for Fedora and Mandriva
* Thu Mar 18 2010 matejcik@suse.cz
- update to 0.6
  * scaling figures/images by percents
  * many improvements in LaTeX2e writer
- fixed insecure usage of temp files in emacs mode
  (bnc#564366)
* Tue Aug 11 2009 matejcik@suse.cz
- build as noarch on new distros
* Wed Aug  5 2009 matejcik@suse.cz
- update to 0.5
  * added hebrew mappings
  * configuration is now in UTF-8
  * minor fixes and refactoring
* Tue Feb 28 2006 jmatejek@suse.cz
- updated to reflect python changes due to #149809
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan 21 2006 cthiel@suse.de
- update to 0.4
* Tue May 31 2005 ltinkl@suse.cz
- update to 0.3.9
* Mon Jan  3 2005 mcihar@suse.cz
- update to 0.3.7
* Fri Jul 30 2004 mcihar@suse.cz
- update to 0.3.5
* Mon May 31 2004 mcihar@suse.cz
- updated to 0.3.3-alpha
* Thu Mar 18 2004 mcihar@suse.cz
- corrected python dependency
* Tue Feb 10 2004 vinil@suse.cz
- initial version (CVS from 2004-02-10)
